@@ -1,14 +1,110 @@
 <?php
 
 
+/**
+  * SquirrelMail Taglines Plugin
+  * Copyright (C) 2002-2004 Tracy McKibben, Paul Lesneiwski <pdontthink@angrynerds.com>
+  * This program is licensed under GPL. See COPYING for details
+  *
+  */
+
+
+   function taglines_options_do()
+   {
+
+      global $taglines_allow_overrides, $taglines_enable_default,
+             $data_dir, $username;
+
+      include_once(SM_PATH . 'plugins/taglines/config.php');
+
+
+      // bail if admin is disallowing user settings
+      //
+      if (!$taglines_allow_overrides) return;
+
+
+      $taglines_enable = getPref($data_dir, $username, 'taglines_enable', $taglines_enable_default);
+
+      bindtextdomain('taglines', SM_PATH . 'plugins/taglines/locale');
+      textdomain('taglines');
+
+      global $optpage_data;
+      $optpage_data['vals'][2][] = array(
+         'name'          => 'taglines_enable',
+         'caption'       => _("Append Random Phrase to Messages"),
+         'type'          => SMOPT_TYPE_BOOLEAN,
+         'initial_value' => $taglines_enable,
+         'refresh'       => SMOPT_REFRESH_NONE,
+      );
+
+      bindtextdomain('squirrelmail', SM_PATH . 'locale');
+      textdomain('squirrelmail');
+
+   }
+
+
+
+   function taglines_on_off_switch_do()
+   {
+
+      global $taglines_allow_overrides, $taglines_enable_default,
+             $username, $data_dir, $taglines_show_switches_on_compose_page;
+
+      include_once(SM_PATH . 'plugins/taglines/config.php');
+
+
+      if (!$taglines_show_switches_on_compose_page) return;
+
+
+      $taglines_enable = getPref($data_dir, $username, 'taglines_enable', $taglines_enable_default);
+      if (!$taglines_allow_overrides) $taglines_enable = $taglines_enable_default;
+
+
+      if (!$taglines_enable) return;
+
+
+      echo '<br />';
+
+      bindtextdomain('taglines', SM_PATH . 'plugins/taglines/locale');
+      textdomain('taglines');
+
+      echo _("Append Random Phrase");
+
+      bindtextdomain('squirrelmail', SM_PATH . 'locale');
+      textdomain('squirrelmail');
+
+
+      echo ' <input type="radio" name="enable_tagline_override" CHECKED value="1" />' . _("Yes")
+         . '<input type="radio" name="enable_tagline_override" value="0" />' . _("No");
+   
+   }
+
+
+
    function taglines_getquote_do(&$argv) 
    {
 
-      global $fortuneCommand, $taglineSource, $taglinePrefix;
+      global $fortuneCommand, $taglineSource, $taglinePrefix,
+             $taglines_allow_overrides, $taglines_enable_default,
+             $username, $data_dir;
 
       include_once(SM_PATH . 'plugins/taglines/config.php');
 
 
+      $taglines_enable = getPref($data_dir, $username, 'taglines_enable', $taglines_enable_default);
+
+
+      global $enable_tagline_override;
+      sqgetGlobalVar('enable_tagline_override', $enable_tagline_override, SQ_POST);
+      if (!$enable_tagline_override) $taglines_enable = 0;
+
+
+      if (!$taglines_allow_overrides) $taglines_enable = $taglines_enable_default;
+
+
+      if (!$taglines_enable) return;
+
+
       // autodetect taglines source - if fortune program
       // isn't available, only pull from qotd - if fortune program
       // isn't available, only pull from qotd.org
@@ -31,12 +127,10 @@
       if ($taglineSource == 1 || ($taglineSource == 0 && mt_rand(1,20) > 10))
       {
  
-         // if we have access to the taglines directory,
          // check age of cache 
          //
-         $quotesrc = SM_PATH . 'plugins/taglines/qotd.html';
-         if (is_writable(SM_PATH . 'plugins/taglines') 
-          && file_exists($quotesrc))
+         $quotesrc = $data_dir . 'taglines_qotd.html';
+         if (is_writable($quotesrc))
          {
             $filemod     = filemtime($quotesrc);
             $filemodtime = date('F j Y h:i:s A', $filemod);
@@ -95,12 +189,10 @@
          $sString = trim($sString);
 
 
-         // if we have access to the taglines directory
-         // and the cache file is nonexistent, save local
+         // if the cache file is nonexistent, save local
          // copy of web page
          //
-         if (is_writable(SM_PATH . 'plugins/taglines')
-          && !file_exists($quotesrc))
+         if (!file_exists($quotesrc))
          {
             if ($QOTDFILE = fopen($quotesrc, 'w'))
             {
